checkRequire("Lua_SpiritShopItem");
checkRequire("Lua_IconShowItem");
Lua_SpiritShopWindow = class("Lua_SpiritShopWindow", Lua_Window);
function Lua_SpiritShopWindow:ctor()
	self:superCall("ctor");

	self.layer = MainWinDefine.NORMAL_WINDOW_LAYER;
	self.windowName = "Lua_SpiritShopWindow";
	self.skinName = "SpiritShopWindow_skin";
	self.winBgPath = "/images/shop/ui_tmd_bj_001.jpg";
	self.isFullSizeWin = true;
	self.showWinBg = true;
	self.showBackBtn = true;

	self:addPreLoadRes(self.winBgPath, Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/shop/ui_tmd_widget_002.png", Lua_LoadFileType.IMG);
	self:addPreLoadRes("/images/shop/ui_tmd_widget_001.png", Lua_LoadFileType.IMG);
end

function Lua_SpiritShopWindow:buildShowItem()
	self:superCall("buildShowItem");

	self.roleIcon:setEnable(false);
	self.roleIcon:setUrl(nil);
	self.itemList = Lua_DragList.new(self.content, 630, 560, Lua_AxisDefine.Vertical);
	self.itemList:setListCell(Lua_SpiritShopItem, 182, 239, 3);
	self.itemList:setCellSpacing(23, 41);
	self.itemList:setLocation(18, -191, 0);
	self.itemList.canDrag = false;

	self.refreshBtn:addClickFuntion(self, self.onRefreshBtnClick);
	self.introduceSp:addClickFuntion(self, self.onIntroduceSpClick);
	self:updateInfo();

	self:addLuaEvent("UPDATE_SHOP_INFO", self, self.updateShowInfo);
	self:addLuaEvent("MONEY_UPDATE", self, self.onMoneyUpdate);
	self:addLuaEvent("SINGLE_ITEM_UPDATE", self, self.onPackUpdate);
	-- 到达商店刷新时间
	self:addLuaEvent("REFRESH_SHOP_INFO", self, self.updateShopTypePanel);
end

function Lua_SpiritShopWindow:showWin(param)
	self:superCall("showWin", param);

	if type(param) == "table" then
		DataCenter.shopData.shopType = param.secondIdx;
	else
		DataCenter.shopData.shopType = Lua_ShopData.SPIRIT_SHOP;
	end

	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(Lua_ShopData.SPIRIT_SHOP);
end

function Lua_SpiritShopWindow:updateInfo()
	if self.moneyArr == nil then
		self.moneyArr = Array();
	end

	local len = self.moneyArr:getSize();
	for i=1, len do
		self.moneyArr[i]:setEnable(false);
	end

	self.data = DataCenter.shopUtil:getShopTypeVo(Lua_ShopData.SPIRIT_SHOP);
	if self.data.moneyType ~= nil then
		len = #self.data.moneyType;
		local moneyType;
		local item;
		local tvo;
		local haveCount;
		for i = 1, len do
			moneyType = self.data.moneyType[i];
			if self.moneyArr[i] == nil then
				item = Lua_IconShowItem.new(self.content);
				self.moneyArr:add(item);
			else
				item = self.moneyArr[i];
			end
			
			item:setEnable(true);
			item:setLocation(270 - (i - 1) * 175, 672, 0);
			item:setBg(true, nil, nil, 130);
			tvo = Lua_ToolVo.createToolVo(moneyType);
			haveCount = DataCenter.packData:getItemCountById(moneyType);
			item:setIcon(tvo.atlas, tvo.sprite, tvo.iconWidth, tvo.iconHeight);
			item:setIconClick(moneyType);
			item:setAddClick();
			item:setCount(numberTrans(haveCount), "FFFFFF");
		end
	end
end

function Lua_SpiritShopWindow:updateShowInfo()
	local arr = DataCenter.shopData.getCurShopItemArr;
	self.itemList:setArrayData(arr);
	
	if self.data.leftTimes > 0 then 
		if self.data.leftFreeTimes > 0 then
			self.refreshBtn.label = LanUtil.formateStr(125036, tostring(self.data.leftFreeTimes), tostring(self.data.free_refresh));
		else
			self.refreshBtn.label = LanUtil.formateStr(125017, spliceIconStrById(self.data.cost_money), numberTrans(self.data.cost));
		end
	else
		self.refreshBtn:setLangValue(125041);
	end

	self.remainTimeTxt.text = LanUtil.formateStr(125037, tostring(self.data.leftTimes), tostring(self.data.totalTimes));
	self.refreshBtn:setStyle(self.data.leftTimes <= 0 and 7 or 5);

	if self.data.nextTicks > 0 then
		self:startTimer();
	else
		self:updateTimer();
	end
end

function Lua_SpiritShopWindow:startTimer()
	if not self.isTimer then
		self.isTimer = true;
		self:updateTimer();
		self:addTimer("updateTimer", 1, self, self.updateTimer);
	end
end

function Lua_SpiritShopWindow:updateTimer()
	local time = self.data.nextTicks - os.time();
	if time <= 0 then
		time = 0;
		self:removeTimer(self, self.updateTimer);
		self.isTimer = false;	
	end
	self.refreshTimeTxt.text = LanUtil.formateStr(125027, "<color=#3bf25a>"..TimeTransform.getInstance():transSeconds6(time, true, true)).."</color>";
end

function Lua_SpiritShopWindow:onRefreshBtnClick(go)
	if self.clickTime ~= nil and getTime() - self.clickTime < 0.3 then
		OperateAlert.showLangValue(10031);
		return;
	end
	self.clickTime = getTime();
	
	if self.data.leftFreeTimes > 0 then--免费刷新
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 0);
	elseif self.data.leftTimes > 0 then--自费刷新
		if DataCenter.moneyData:isMoney(self.data.cost_money) then
			if not DataCenter.moneyData:isMoneyEnough(self.data.cost_money, self.data.cost, true, true) then
				return;
			end
		else
			if DataCenter.packData:getItemCountById(self.data.cost_money) < self.data.cost then
				DataCenter.packUtil:openPathWindow(self.data.cost_money, false);
				return;
			end
		end
		Lua_ProxyManager.getProxy("Lua_ShopProxy"):sRefreshShop(self.data.shopType, 1);
	elseif self.data.leftBuyTimes > 0 then--购买刷新
		Lua_WindowUtil.openWin("Lua_BuyTimesWindow", Lua_WinParam.ACTION_OPEN, self.data);
	else
		OperateAlert.showLangValue(125020);
	end
end

function Lua_SpiritShopWindow:onMoneyUpdate(dic)
	if dic == nil or self.moneyArr == nil then
		return;
	end

	local moneyType;
	for i = 1, self.moneyArr:getSize() do
		moneyType = self.moneyArr[i].iconId;
		if moneyType ~= nil and dic[moneyType] ~= nil then
			self.moneyArr[i]:setCount(numberTrans(DataCenter.moneyData:getMoney(moneyType)), "FFFFFF");
		end
	end
end

function Lua_SpiritShopWindow:onPackUpdate(vo)
	if vo == nil then
		return;
	end

	for i = 1, self.moneyArr:getSize() do
		if vo.id == self.moneyArr[i].iconId then
			self.moneyArr[i]:setCount(numberTrans(DataCenter.packData:getItemCountById(vo.id)), "FFFFFF");
			break;
		end
	end
end

function Lua_SpiritShopWindow:onIntroduceSpClick()
	local tipsData = { des = LanUtil.getValue(125043), posX = 199, posY = -303 };
	Lua_WindowUtil.openWin("Lua_InstructionTipsWindow", Lua_WinParam.ACTION_OPEN, tipsData);
end

function Lua_SpiritShopWindow:updateShopTypePanel()
	Lua_ProxyManager.getProxy("Lua_ShopProxy"):sShopInfo(Lua_ShopData.SPIRIT_SHOP);
end

function Lua_SpiritShopWindow:dispose()
	if self.moneyArr ~= nil then
    	self.moneyArr:dispose();
   		self.moneyArr:clear();
   		self.moneyArr = nil;
   	end
   	if self.itemList ~= nil then
		self.itemList:dispose();
		self.itemList = nil;
	end
	DataCenter.shopData:dispose();

	self:superCall("dispose");
end